Rebrand to flashprog and update URLs

Mostly automated `sed` work. As of now, URLs to the old wiki are broken
either way, so changing them shouldn't hurt. Other URLs (e.g. to mailing
list archives) were hopefully filtered correctly.

Change-Id: I9d43bfd0e675eff2fcbad05f304b9ce9f5006b08
Signed-off-by: Nico Huber <nico.h@gmx.de>
Reviewed-on: https://review.sourcearcade.org/c/flashrom-stable/+/21
diff --git a/dediprog.c b/dediprog.c
index dfbb949..866d628 100644
--- a/dediprog.c
+++ b/dediprog.c
@@ -136,7 +136,7 @@
 };
 
 /*
  * These are not official designations; they are for use in flashrom only.
  * Order must be preserved so that comparison operators work.
  */
 enum protocol {
@@ -374,7 +374,7 @@
 
 	if (count >= 1 << 16) {
 		msg_perr("%s: Unsupported transfer length of %u blocks!\n"
-			 "Please report a bug at flashrom-stable@flashrom.org\n",
+			 "Please report a bug at flashprog@flashprog.org\n",
 			 __func__, count);
 		return 1;
 	}
@@ -458,7 +458,7 @@
 
 	if ((start % chunksize) || (len % chunksize)) {
 		msg_perr("%s: Unaligned start=%i, len=%i!\n"
-			 "Please report a bug at flashrom-stable@flashrom.org\n",
+			 "Please report a bug at flashprog@flashprog.org\n",
 			 __func__, start, len);
 		return 1;
 	}
@@ -608,14 +608,14 @@
 	 */
 	if (chunksize != 256) {
 		msg_perr("%s: Chunk sizes other than 256 bytes are unsupported, chunksize=%u!\n"
-			 "Please report a bug at flashrom-stable@flashrom.org\n",
+			 "Please report a bug at flashprog@flashprog.org\n",
 			 __func__, chunksize);
 		return 1;
 	}
 
 	if ((start % chunksize) || (len % chunksize)) {
 		msg_perr("%s: Unaligned start=%i, len=%i!\n"
-			 "Please report a bug at flashrom-stable@flashrom.org\n",
+			 "Please report a bug at flashprog@flashprog.org\n",
 			 __func__, start, len);
 		return 1;
 	}
@@ -1231,7 +1231,7 @@
 			 * libusb_set_configuration() and
 			 * libusb_claim_interface(). When searching by id and
 			 * either configuration or claim fails (usually the
 			 * device is in use by another instance of flashrom),
 			 * the device is skipped and the next device is tried.
 			 */
 			found_id = dediprog_read_id(dp_data->handle);
@@ -136,7 +136,7 @@
 
 /*
- * These are not official designations; they are for use in flashrom only.
+ * These are not official designations; they are for use in flashprog only.
  * Order must be preserved so that comparison operators work.
  */
@@ -1231,7 +1231,7 @@
 			 * libusb_claim_interface(). When searching by id and
 			 * either configuration or claim fails (usually the
-			 * device is in use by another instance of flashrom),
+			 * device is in use by another instance of flashprog),
 			 * the device is skipped and the next device is tried.
 			 */